# scrapwithgpt

In your virtual environment, do "pip install scrapwithgpt".

Then "from scrapwithgpt import smartscrap".

You can also use/import the default config for the filtering, the output and the example.


Then call smartscrap(). Example of usage in the scrap.py module.